# History

## 0.1.1 (2023-07-05)
### Changed 
- Improved the README.md file. 
### Added 
- Correctly formatted docstrings of all modules, including the utility files. 
- Documentation page on readthedocs.org. 
### Deprecated 
- 0.1.1 will be the last version that contains the 
  ``distinct_variants_evol()`` plotting method, and will be removed in the 
  next minor update. Reason being: the method solely duplicates a small part 
  of the visualization capabilities offered by the 
  ``distinct_variants_AdvancedEvol()`` method. Use the more extensive 
  ``distinct_variants_AdvancedEvol()`` visualization method instead.

## 0.1.0 (2023-06-21)
- First release on PyPI.
